@@ -8,7 +8,7 @@ css_file = os.path.join(parent_dir, "style.css")
 
 def st_menu(menu_items={}, header={}, divider_between_header_and_body=True, header_style={}, wrapper_style={}, submenu_style={}, single_menu_style={}, is_collapsible=False, on_menu_select=None, args=None):
     with st.sidebar:
-        selected_maneu = getMenu(menu_items=menu_items,
+        getMenu(menu_items=menu_items,
                 header=header,
                 divider_between_header_and_body=divider_between_header_and_body,
                 header_style=header_style,
@@ -20,4 +20,4 @@ def st_menu(menu_items={}, header={}, divider_between_header_and_body=True, head
                 on_select=on_menu_select,
                 args=args)
 
-    return selected_maneu["title"]
+    return st.session_state["sidemenu"]
